#version 330

in vec3 worldNormal;
in vec2 fragmentUV;
in vec3 surfacePosition;
in vec3 surfaceNormal;

out vec4 fragColor;

uniform sampler2D colorTexture;
uniform float specExp;
uniform vec3 Ld;
uniform vec3 Ls;
uniform vec3 lightPosition;
uniform vec3 cameraPosition;
uniform float lightPower;

void main()
{
	vec3 textureColor = texture(colorTexture, fragmentUV).rgb;

	fragColor = vec4(textureColor, 1.0);
	
	vec3 n_viewVector = normalize(cameraPosition - surfacePosition);
	vec3 n_surfaceNormal = normalize(surfaceNormal);
	vec3 n_lightDirection = normalize(lightPosition - surfacePosition);
	vec3 n_halfwayVector = normalize(n_viewVector + n_lightDirection);
		
	//vec4 Ia = vec4(material, 1.0);
	vec3 Id = Ld * max(dot(n_lightDirection, n_surfaceNormal), 0.0) * lightPower;
	vec3 Is = Ls * pow(max(dot(n_halfwayVector, n_surfaceNormal), 0.0), specExp);
		
	vec4 I = vec4(Id, 0.0f) + vec4(Is, 0.0f);
	fragColor += I;
}