#version 330

uniform mat4 projectionMatrix;
uniform mat4 modelMatrix;
uniform mat4 viewMatrix;
uniform mat4 bonesMatrix[32];

in vec3 position;
in vec3 normal;
in vec4 weights;
in ivec4 joints;

out vec3 worldNormal;
out vec3 surfacePosition;
out vec3 surfaceNormal;

void main(void) {	
	mat4 animationMatrix =
    weights[0] * bonesMatrix[joints[0]] +
    weights[1] * bonesMatrix[joints[1]] +
    weights[2] * bonesMatrix[joints[2]] +
	weights[3] * bonesMatrix[joints[3]];
	
	surfacePosition = vec3(animationMatrix * vec4(position, 1.0));
	surfaceNormal = normalize(transpose(mat3(inverse(animationMatrix))) * normal);

	worldNormal = (modelMatrix * vec4(normal, 0)).xyz;
	
	//modelMatrix is already multiplicated in the animationMatrix
	gl_Position = projectionMatrix * viewMatrix * animationMatrix *vec4(position, 1);
}
