#version 330

in vec3 worldNormal;
in vec2 fragmentUV;
in vec3 surfacePosition;
in vec3 surfaceNormal;
in vec4 shadow_tex_coord;

out vec4 fragColor;

uniform sampler2D shadow_map; // shadow map is just a texture
uniform sampler2D colorTexture;
uniform float lightPower;
uniform float specExp;
uniform vec3 Ld;
uniform vec3 Ls;
uniform vec3 lightPosition;
uniform vec3 cameraPosition;

void main()
{
	// perform perspective division
	vec3 tex_coords = shadow_tex_coord.xyz/shadow_tex_coord.w;
	// read depth value from shadow map
	float depth = texture(shadow_map, tex_coords.xy).r;
	float inShadow = (depth < tex_coords.z) ? 0.0f : 1.0f;

	vec4 textureColor = texture(colorTexture, fragmentUV).rgba;

	fragColor = vec4(textureColor);
	
	vec3 n_viewVector = normalize(cameraPosition - surfacePosition);
	vec3 n_surfaceNormal = normalize(surfaceNormal);
	vec3 lightDirection = lightPosition - surfacePosition;
	vec3 n_lightDirection = normalize(lightDirection);
	vec3 n_halfwayVector = normalize(n_viewVector + n_lightDirection);

	vec3 Id = Ld * max(dot(n_lightDirection, n_surfaceNormal), 0.0) * lightPower;
	vec3 Is = vec3(0.0f);//Ls * pow(max(dot(n_halfwayVector, n_surfaceNormal), 0.0), specExp) * 0.7;
		
	vec4 I = vec4(Id, 0.0f) + vec4(Is, 0.0f);
	fragColor += I; 
	
	fragColor=vec4((fragColor*(0.5+inShadow*0.5)).xyz,1); //TODO:richtiges Beleuchtungsmodell

	//fragColor =vec4(vec3(inShadow),1); //Test
}